IBCAPI class

Inheritance

Constructors

IBCAPI(TerraRestfulService apiRequester)

Properties

apiRequester → TerraRestfulService
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getClientStateByID(String clientId) → Future<IdentifiedClientState>
getClientStates() → Future<List<IdentifiedClientState>>
getClientStatusByID(String clientId) → Future<String>
getConsensusStateByID(String clientId) → Future<List<ClientConsensusStates>>
getParameters() → Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited