StakingAPI class

Inheritance

Constructors

StakingAPI(TerraRestfulService apiRequester)

Properties

apiRequester → TerraRestfulService
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBondedValidators(String delegator) → Future<List<Validator>>
getDelegations({String delegator = "", String validator = "", PaginationOptions? options}) → Future<List<Delegation>>
getRedelegations(String delegator, String? validatorSrc, String? validatorDst) → Future<List<RedelegationResponseJSON>>
getStakingParameters() → Future<StakingApiParams>
getStakingPool() → Future<StakingPoolJSON>
getUnbondingDelegation(String delegator, String validator) → Future<List<UnbondingDelegation>>
getUnbondingDelegations(String delegator, String validator, {PaginationOptions? options}) → Future<UnbondingDelegation>
getValidator(String validator) → Future<Validator>
getValidators() → Future<List<Validator>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited