TreasuryAPI class

Inheritance

Constructors

TreasuryAPI(TerraRestfulService apiRequester)

Properties

apiRequester → TerraRestfulService
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getGasPriceForDenom(String feeDenom) → Future<double>
getGasPrices() → Future<DenomGasPrices>
getParameters() → Future<TreasuryTaxPolicy>
getRewardWeight() → Future<double>
getTaxCap(String denom) → Future<double>
getTaxCaps() → Future<List<Coin>>
getTaxProceeds() → Future<double>
getTaxRate() → Future<double>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seigniorageProceeds() → Future<Coin>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited