TxAPI class

Inheritance

Constructors

TxAPI(TerraRestfulService apiRequester)

Properties

apiRequester → TerraRestfulService
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTxHashesByBlockHeight(int? height) → Future<List<String>>
getTxInfo(String txHash) → Future<TxResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited