Wallet class

Constructors

Wallet(LcdClient _lcd, String accAddress, TxBroadcastAPI _broadcastTx)

Properties

accAddress → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccountNumber() → Future<int>
getAccountNumberAndSequence() → Future<Map<double, double>>
getSequence() → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited