MsgExecAuthorized class

Constructors

MsgExecAuthorized(String grantee, List<Any> msgs)

Properties

grantee → String
final
hashCode → int
The hash code for this object.
no setterinherited
msgs → List<Any>
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgExecAuthorizedAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgExecAuthorizedDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited