MsgExecAuthorizedDataArgs class

Constructors

MsgExecAuthorizedDataArgs(String grantee, List<Any> msgs)

Properties

grantee ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
msgs ↔ List<Any>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited