Output class

Constructors

Output(String address, List<Coin> coins)

Properties

address ↔ String
getter/setter pair
coins ↔ List<Coin>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → OutputAminoArgs
toData() → OutputDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(OutputAminoArgs data) → Output
fromData(OutputDataArgs data) → Output