MsgSend class

Constructors

MsgSend(String from_address, String to_address, List<Coin> amount)

Properties

amount → List<Coin>
final
from_address → String
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
to_address → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgSendAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgSendDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(MsgSendAminoArgs data) → MsgSend
fromData(MsgSendDataArgs data) → MsgSend