MsgSendDataArgs class

Constructors

MsgSendDataArgs(String from_Address, String to_Address, List<CoinDataArgs> amount)

Properties

amount ↔ List<CoinDataArgs>
getter/setter pair
from_Address ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to_Address ↔ String
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited