MsgFundCommunityPool class

Constructors

MsgFundCommunityPool(String depositor, List<Coin> amount)

Properties

amount → List<Coin>
final
depositor → String
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgFundCommunityPoolAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgFundCommunityPoolDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited