MsgSetWithdrawAddressValueAminoArgs class

Constructors

MsgSetWithdrawAddressValueAminoArgs(String delegator_address, String withdraw_address)

Properties

delegator_address → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withdraw_address → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited