CommunityPoolSpendProposal class

Constructors

CommunityPoolSpendProposal(String title, String description, String recipient, List<Coin> amount)

Properties

amount → List<Coin>
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
recipient → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → CommunityPoolSpendProposalAminoArgs
toData() → CommunityPoolSpendProposalDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited