CommunityPoolSpendProposalDataArgs class

Constructors

CommunityPoolSpendProposalDataArgs(String title, String description, String recipient, List<CoinDataArgs> amount)

Properties

amount → List<CoinDataArgs>
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
recipient → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited