TerraStringExtensions class

Constructors

TerraStringExtensions()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

containsIgnoreCase(String source, String verify) → bool
getISODateTimeFromString(String dateTime) → DateTime
getISOStringFromDate(DateTime date) → String
getRandomString({int length = 10}) → String
toCleanHex(List<int> bytes) → String