Proposal class

Constructors

Proposal(double id, ProposalStatus status, FinalTallyResult final_tally_result, DateTime submit_time, DateTime deposit_end_time, List<Coin> total_deposit, DateTime voting_start_time, DateTime voting_end_time, ProposalContent content)

Properties

content ↔ ProposalContent
getter/setter pair
deposit_end_time ↔ DateTime
getter/setter pair
final_tally_result ↔ FinalTallyResult
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ProposalStatus
getter/setter pair
submit_time ↔ DateTime
getter/setter pair
total_deposit ↔ List<Coin>
getter/setter pair
voting_end_time ↔ DateTime
getter/setter pair
voting_start_time ↔ DateTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → CommonProposalArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(dynamic data) → dynamic
fromData(dynamic data) → dynamic
fromJSON(ProposalsResponseContainerValueJSON data) → Proposal