MsgTransfer class

Constructors

MsgTransfer(String source_port, String source_channel, Coin token, String sender, String receiver, Height timeout_height, double timeout_timestamp)

Properties

hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
receiver → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String
final
sequenceNumber ↔ double?
getter/setter pairinherited
source_channel → String
final
source_port → String
final
timeout_height → Height
final
timeout_timestamp → double
final
token → Coin
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgTransferAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgTransferDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited