MsgChannelOpenInit class

Constructors

MsgChannelOpenInit(String port_id, Channel channel, String signer)

Properties

channel → Channel
final
hashCode → int
The hash code for this object.
no setterinherited
port_id → String
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgChannelOpenInitDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited