MsgChannelOpenTry class

Constructors

MsgChannelOpenTry(String port_id, String previous_channel_id, Channel channel, String counterparty_version, String proof_init, Height proof_height, String signer)

Properties

channel → Channel
final
counterparty_version → String
final
hashCode → int
The hash code for this object.
no setterinherited
port_id → String
final
previous_channel_id → String
final
proof_height → Height
final
proof_init → String
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgChannelOpenTryDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited