MsgChannelOpenTryCommonArgs class

Implementers

Properties

channel ↔ ChannelDataArgs?
getter/setter pair
counterparty_Version ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
port_id ↔ String?
getter/setter pair
previous_Channel_Id ↔ String?
getter/setter pair
proof_Height ↔ HeightDataArgs?
getter/setter pair
proof_Init ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signer ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited