MsgChannelOpenTryDataArgs class

Inheritance

Constructors

MsgChannelOpenTryDataArgs()

Properties

channel ↔ ChannelDataArgs?
getter/setter pairinherited
counterparty_Version ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
port_id ↔ String?
getter/setter pairinherited
previous_Channel_Id ↔ String?
getter/setter pairinherited
proof_Height ↔ HeightDataArgs?
getter/setter pairinherited
proof_Init ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signer ↔ String?
getter/setter pairinherited
type ↔ String?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited