Height class

Constructors

Height(double revision_number, double revision_height)

Properties

hashCode → int
The hash code for this object.
no setterinherited
revision_height → double
final
revision_number → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → HeightAminoArgs
toData() → HeightDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(HeightAminoArgs data) → Height
fromData(HeightDataArgs data) → Height
fromJSON(HeightJSON data) → Height