MsgUpgradeClient class

Constructors

MsgUpgradeClient(String client_id, Any client_state, Any consensus_state, String proof_upgrade_client, String proof_upgrade_consensus_state, String signer)

Properties

client_id → String
final
client_state → Any
final
consensus_state → Any
final
hashCode → int
The hash code for this object.
no setterinherited
proof_upgrade_client → String
final
proof_upgrade_consensus_state → String
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgUpgradeClientDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited