ClientUpdateProposal class

Constructors

ClientUpdateProposal(String title, String description, String subjectClientId, String substituteClientId)

Properties

description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subjectClientId ↔ String
getter/setter pair
substituteClientId ↔ String
getter/setter pair
title ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → ClientUpdateProposalAminoArgs
toData() → ClientUpdateProposalDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited