ValConsKey class

Constructors

ValConsKey(String key)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → ValConsKeyAminoArgs
toData() → ValConsKeyDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(ValConsKeyAminoArgs data) → ValConsKey
fromData(ValConsKeyDataArgs data) → ValConsKey
fromJSON(ValConsPublicKeyCommonArgsJSON data) → ValConsKey