MsgSwapSend class

Constructors

MsgSwapSend(String from_address, String to_address, Coin offer_coin, String ask_denom)

Properties

ask_denom → String
final
from_address → String
final
hashCode → int
The hash code for this object.
no setterinherited
offer_coin → Coin
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
to_address → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgSwapSendAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgSwapSendDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited