ExchangeRateTuple class

Constructors

ExchangeRateTuple(double? exchange_rate, double? denom)

Properties

denom → double?
final
exchange_rate → double?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → ExchangeRateTupleCommonArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited