MsgDelegateFeedConsent class

Constructors

MsgDelegateFeedConsent(String coperator, String cdelegate)

Properties

cdelegate → String
final
coperator → String
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgDelegateFeedConsentAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgDelegateFeedConsentDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited