Entry class

Constructors

Entry(int initial_balance, int balance, double shares_dst, double creation_height, DateTime completion_time)

Properties

balance → int
final
completion_time → DateTime
final
creation_height → double
final
hashCode → int
The hash code for this object.
no setterinherited
initial_balance → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shares_dst → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → EntryAminoArgs
toData() → EntryDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(EntryAminoArgs data) → Entry
fromData(EntryDataArgs data) → Entry