MsgBeginRedelegate class

Constructors

MsgBeginRedelegate(String delegator_address, String validator_src_address, String validator_dst_address, Coin amount)

Properties

amount → Coin
final
delegator_address → String
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
validator_dst_address → String
final
validator_src_address → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgBeginRedelegateAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgBeginRedelegateDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited