MsgEditValidator class

Constructors

MsgEditValidator(ValidatorDescription description, double commission_rate, int min_self_delegation, String validator_address)

Properties

commission_rate → double
final
description → ValidatorDescription
final
hashCode → int
The hash code for this object.
no setterinherited
min_self_delegation → int
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
validator_address → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgEditValidatorAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgEditValidatorDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited