Validator class

Constructors

Validator(String operator_address, ValConsKey consensus_pubkey, bool jailed, BondStatus status, double tokens, double delegator_shares, ValidatorDescription description, double unbonding_height, DateTime unbonding_time, Commission commission, double min_self_delegation)

Properties

commission ↔ Commission
getter/setter pair
consensus_pubkey ↔ ValConsKey
getter/setter pair
delegator_shares ↔ double
getter/setter pair
description ↔ ValidatorDescription
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jailed ↔ bool
getter/setter pair
min_self_delegation ↔ double
getter/setter pair
operator_address ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ BondStatus
getter/setter pair
tokens ↔ double
getter/setter pair
unbonding_height ↔ double
getter/setter pair
unbonding_time ↔ DateTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → ValidatorDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(ValidatorDataArgs data) → Validator
fromJSON(ValidatorDataArgsJSON data) → Validator