ValidatorDataArgs class

Inheritance

Constructors

ValidatorDataArgs()

Properties

commission ↔ CommissionCommonArgs?
getter/setter pair
consensus_pubkey ↔ ValConsKeyDataArgs?
getter/setter pair
delegator_shares ↔ String?
getter/setter pairinherited
description ↔ ValidatorDescriptionCommonArgs?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jailed ↔ bool?
getter/setter pairinherited
min_Self_Delegation ↔ String?
getter/setter pairinherited
operator_Address ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ BondStatus?
getter/setter pairinherited
tokens ↔ String?
getter/setter pairinherited
unbonding_Height ↔ String?
getter/setter pairinherited
unbonding_Time ↔ String?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited