ValidatorDescription class

Constructors

ValidatorDescription(String moniker, String identity, String website, String details, String security_contact)

Properties

details → String
final
hashCode → int
The hash code for this object.
no setterinherited
identity → String
final
moniker → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
security_contact → String
final
website → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → ValidatorDescriptionCommonArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(ValidatorDescriptionCommonArgs data) → ValidatorDescription
fromJSON(ValidatorDescriptionJSON data) → ValidatorDescription