MsgMigrateCode class

Constructors

MsgMigrateCode(String sender, double code_id, String wasm_byte_code)

Properties

code_id → double
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String
final
sequenceNumber ↔ double?
getter/setter pairinherited
wasm_byte_code → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgMigrateCodeAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgMigrateCodeDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited