MsgUpdateContractAdmin class

Constructors

MsgUpdateContractAdmin(String admin, String contract, String new_admin)

Properties

admin → String
final
contract → String
final
hashCode → int
The hash code for this object.
no setterinherited
new_admin → String
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgUpdateContractAdminAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgUpdateContractAdminDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited