Coin class

Constructors

Coin(String? denom, double? amount)

Properties

amount → double?
final
denom → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(dynamic value) → Coin
div(dynamic value) → Coin
mod(dynamic value) → Coin
mul(dynamic value) → Coin
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sub(dynamic value) → Coin
toAmino() → CoinAminoArgs
toData() → CoinDataArgs
toDecCoin() → Coin
toJSON() → CoinJSON
toLongCeilCoin() → Coin
toLongCoin() → Coin
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(CoinAminoArgs data) → Coin
fromData(CoinDataArgs data) → Coin
fromJSON(CoinJSON data) → Coin
fromString(String str) → Coin